%=============================================================
%               Exemple de code pour le TPA03 : 
%           Donnes environnementales et effet de serre
%               (Indicateurs bidimensionnels)
%
%   1ere Partie : Etudes des tempratures
%
clear all; clc; close all;
%=============================================================
% Acquisition des donnes et initialisations
%-------------------------------------------------------------
% DONNEES des tempratures (priode 1/1982  12/2010)
load clim_t2C_J1982D2010;  % Temperature at 2 meters (degC)  de 1/1982  12/2010
%
% Initialisations utiles pour la suite
lieux = {'Reykjavik','Oslo','Paris','New York','Tunis','Alger','Beyrouth','Atlan','Dakar'};
[Ndata, nblieux]  = size(clim_t2(:,3:end)); 
%
% Pour la labellisation de l'axe des x avec les annes (au mois de janvier)
Ilab = find(clim_t2(:,2)==1); % Indices des mois de janvier
Xlab = clim_t2(Ilab,1);       % On rcupre les annes de ces indices
%
%=============================================================
fprintf('\n1) Etude statique des tempratures\n'); 
%-------------------------------------------------------------
%
fprintf('\n1.1) Affichage de t2 (brut) toutes villes\n');
%-------------------------------------------------------------
plotclimt2(clim_t2);
%
%-------------------------------------------------------------
fprintf('\n1.2) Coefficients de corrlation linaire entre ville pour t2\n');
%-------------------------------------------------------------
R = corrcoef(clim_t2(:,3:end));
figure; imagesc(R); 
h=colorbar; set(h,'fontsize',12)
title('t2 : coefficients de corrlation entre ville');
%
%-------------------------------------------------------------
fprintf('\n1.3) Diagrammes de dispersion t2 (brut) par ville 2  2\n'); 
%-------------------------------------------------------------
% Cration d'une map de couleur pour reprrer les mois
figure
Map = hot;  hold on     % (create also a figure); or may be hot
colstep = floor(length(Map)/12);
Col = Map(1:colstep:end,:);
%
% 1) les villes entre elles (pour la variable)
k=0;
for i=1:nblieux-1
    for j=i+1:nblieux
        k=k+1;
        subplot(6,6,k); hold on; 
        for month=1:12
            Im = find(clim_t2(:,2)==month);
            plot(clim_t2(Im,i+2),clim_t2(Im,j+2),'.','color',Col(month,:)); 
        end
        axis equal; 
        %
        title(sprintf('r=%.2f',R(i,j)),'VerticalAlignment','middle','fontweight','bold','fontsize',12);
        xlabel(lieux{i},'fontsize',14,'fontweight','demi',...
         'HorizontalAlignment','left','VerticalAlignment','bottom'); 
        ylabel(lieux{j},'fontsize',14,'fontweight','demi');
        set(gca,'fontsize',12,'fontweight','demi')
    end
end
legend('janv','fvr','mars','avril','mai','juin','juil','aout','sept','oct','nov','dc')
%
% Ce n'est pas ais, en l'abscence d'une fonction suptitle
% de placer un titre au bon endroit ... automatiquement
subplot(6,6,1); hold on;
xt=min(clim_t2(:,3)); yt=max(clim_t2(:,3));
text(xt,yt*1.05,'t2 (brutes) : diagramme de dispersion par ville 2  2','fontsize',14,'fontweight','demi');
%
%=============================================================
fprintf('\n2) Etude de l''volution temporelles des tempratures\n'); 
%-------------------------------------------------------------
% >>>>>>>> CHOISIR ICI SA PERIODE D'ETUDE <<<<<<<<<<
andeb=1982; anfin=2010;  % Annes de dbut et de fin
%andeb=2001; anfin=2010; % Annes de dbut et de fin
%
% Moyennes mensuelles des villes sur la periode
Iper=find(clim_t2(:,1)>=andeb & clim_t2(:,1)<=anfin);
clim_t2 = clim_t2(Iper,:);
t2moy   = mean(clim_t2(:,3:end),2); 
Nt2moy  = length(t2moy);
%
%-------------------------------------------------------------
fprintf('\n2.1) t2moy : tempratures moyennes mensuelles'); 
fprintf('\n             + regression et augmentation \n');
%-------------------------------------------------------------
figure; hold on
plot(t2moy,'-k');
%
% - Rgression sur les tempratures moyennes mensuelles (t2moy)
[b0m, b1m, hr] = regtrace([1:Nt2moy]',t2moy,'-b');
set(hr,'linewidth',1.3);
axis tight;
set(gca,'XTick',Ilab, 'XTickLabel',Xlab); 
title(sprintf('t2moy : tempratures moyennes mensuelles de %i  %i et rgression : b0=%f, pente b1=%f', andeb,anfin,b0m,b1m));
%
% - Augmentation de la Temprature sur la Priode
AugmenTP = b1m * (Nt2moy-1);    % Pente x (nbre pas) 
fprintf('t2moy: Augmentation, selon la rgression, sur la priode %i  %i : %.2f degrs\n', andeb,anfin,AugmenTP);
%
% - Augmentation et Temprature  100 ans
Horizon = 1200; % Delai de prvision  Horizon mois car t2moy est en donne mensuelle (soit Horizon/12 annes) 
AugmenTH = b1m * Horizon; % Augmentation de la Temprature sur le Dlai de prvision
Tprev = b0m + b1m*(Nt2moy-1) + AugmenTH;
fprintf('t2moy: Prvision, selon la rgression,  %i ans :\n\tAugmentation : %.2f \t soit Temprature : %.2fC\n', Horizon/12,AugmenTH,Tprev);
%
%-------------------------------------------------------------
fprintf('\n2.2) t2moyan : tempratures moyennes annuelles,'); 
fprintf('\n               + regression et augmentation \n');
%-------------------------------------------------------------
% Calcul de t2moyan (Tempratures moyennes annuelles)
ia=1; % Indice de l'anne dans le vecteur  construire des moyennes annuelles
for an=andeb:anfin
    Ian=find(clim_t2(:,1)==an);
    t2moyan(ia) = mean(t2moy(Ian)); 
    ia=ia+1; 
end
Nt2moyan = length(t2moyan); % Nombre de donnes de moyenne annuelle 
%                             (=nombre d'annes de la periode choisie)
figure; hold on;
plot(t2moyan,'-*','linewidth',1.3);
%
% Rgression sur les tempratures moyennes annuelles (t2moyan)
[b0a, b1a, hr] = regtrace([1:Nt2moyan],t2moyan,'-m');
set(hr,'linewidth',1.3);
axis tight;
set(gca,'XTick',[1:Nt2moyan], 'XTickLabel',[andeb:anfin]);
title(sprintf('t2moyan : tempratures moyennes annuelles de %i  %i et rgression : b0=%f, pente b1=%f', andeb,anfin,b0a,b1a));
%
% Augmentation de la temprature sur la priode de regression 
augmenT  = b1a * (Nt2moyan-1);       % pente x (nbre pas-1)
fprintf('t2moyan: Augmentation, selon la rgression, sur la priode %i  %i : %.2f\n', andeb,anfin,augmenT);
%
% Augmentation et Temprature  100 ans
Horizon = 100; % Delai de prvision  Horizon annes (ici t2moyan est en donne annuelle) 
AugmenTH = b1a * Horizon; % Augmentation de la Temprature sur le Dlai de prvision
Tprev = b0a + b1a*(Nt2moyan-1) + AugmenTH;
fprintf('t2moyan: Prvision, selon la rgression,  %i ans :\n\tAugmentation : %.2f \t soit Temprature : %.2fC\n', Horizon,AugmenTH,Tprev);
%
%-------------------------------------------------------------
fprintf('\n2.3) Intervalle de confiance (Test de STUDENT) pour la pente et la prvision\n');
%-------------------------------------------------------------
alpha=0.05;                % Risque d'erreur retenu
%______________
fprintf('\n> Test et Intervalles avec les tempratures moyennes mensuelles, t2moy de %d  %d\n',andeb,anfin'); 
Horizon = 1200;            % Distance de Projection (pour la Prvision) 
%                          % ici en mois car t2moy est en donne mensuellle (1200 mois => 100 ans)
x0 = Nt2moy-1 + Horizon;   % Points (temps t) de la prvision
%
% Intervalles de confiance (pour la pente et la prvision)
[b1Inf,b1Sup,yc0,y0PrevInf,y0PrevSup] = regtest([1:Nt2moy]',t2moy,b0m,b1m,alpha,x0);
%
% Affichage des rsultats : 
% Pente : 
fprintf('\t # pente b1=%f IC=[%f %f]\n',b1m,b1Inf,b1Sup); % Intervalle de confiance
AugmenTHInf = b1Inf*Horizon;        % Augmentation pour la borne Inf
AugmenTHSup = b1Sup*Horizon;        % Augmentation pour la borne Sup
fprintf('\t       -> Augmentation sur %i ans [%.2f %.2f]C\n', Horizon/12,AugmenTHInf,AugmenTHSup);
%
% Prevision : Intervalle de confiance
fprintf('\t # prevision pour %d (soit dans %d ans) :',anfin+Horizon/12, Horizon/12); 
fprintf(': %.2fC, IC=[%.2f %.2f]C\n',yc0, y0PrevInf, y0PrevSup);
%______________
fprintf('\n> Test et Intervalles avec les tempratures moyennes annuelles, t2moyan de %d  %d\n',andeb,anfin); 
Horizon = 100;              % Distance de Projection (pour la Prvision) ici en anne car ...
x0 = Nt2moyan-1 + Horizon;  % Points (temps t) de la prvision
%
% Intervalles de confiance (pour la pente et la prvision)
[b1Inf,b1Sup,yc0,y0PrevInf,y0PrevSup] = regtest([1:Nt2moyan],t2moyan,b0a,b1a,alpha,x0);
%
% Affichage des rsultats : 
% Pente :
fprintf('\t # pente b1=%f IC=[%f %f]\n',b1a,b1Inf,b1Sup); % Intervalle de confiance
AugmenTHInf = b1Inf*Horizon;        % Augmentation pour la borne Inf
AugmenTHSup = b1Sup*Horizon;        % Augmentation pour la borne Sup
fprintf('\t       -> Augmentation sur %i ans [%.2f %.2f]C\n', Horizon,AugmenTHInf,AugmenTHSup);
%
% Prevision : Intervalle de confiance
fprintf('\t # prevision pour %d (soit dans %d ans) :',anfin+Horizon, Horizon); 
fprintf(': %.2fC, IC=[%.2f %.2f]C\n',yc0, y0PrevInf, y0PrevSup);
%
%=============================================================
%
