%=============================================================
%               Exemple de code pour le TPA03 : 
%           Donnes environnementales et effet de serre
%               (Indicateurs bidimensionnels)
%
%   2me Partie : Tempratures et CO2
%
close all; clear all; clc
%=============================================================
% Acquisition des donnes et initialisations
%-------------------------------------------------------------
% DONNEES de CO2 (priode 1/1982  12/2010)
load clim_co2_J1982D2010; % CO2 molfrac en ppm (partie par million) de 1/1982  12/2010
%
% Initialisations utiles pour la suite
Ndata = length(clim_co2);
tclim = [1:Ndata]'; 
%
% Pour la labellisation de l'axe des x avec les annes (au mois de janvier)
Ilab = find(clim_co2(:,2)==1);    % Indices des mois de janvier
Xlab = clim_co2(Ilab,1);          % On rcupre les annes de ces indices
%
% DONNEES des tempratures (priode 1/1982  12/2010)
load clim_t2C_J1982D2010;         % Temperature at 2 meters (degC)  de 1/1982  12/2010
t2moy = mean(clim_t2(:,3:end),2); % Moyennes
%
%=============================================================
fprintf('\n1) CO2 (brut) et regression\n');
%-------------------------------------------------------------
figure; hold on
plot(clim_co2(:,3),'-b'); axis tight;          
[b0,b1] = regtrace(tclim,clim_co2(:,3),'-m');  % rgression du CO2 
set(gca,'XTick',Ilab, 'XTickLabel',Xlab); 
title(['CO2 (ppm), pente b1=',num2str(b1)]);
% 
%=============================================================
fprintf('\n2) CO2 corrig\n');
%-------------------------------------------------------------
figure; hold on
CO2cor = clim_co2(:,3) - b1*tclim ;             % correction du CO2
plot(CO2cor,'-k'); axis tight;
set(gca,'XTick',Ilab, 'XTickLabel',Xlab); 
title('CO2 corrig = CO2 - b1*tclim');
%
%=============================================================
fprintf('\n3) CO2 corrig dcal\n');
%-------------------------------------------------------------
fprintf('\n3.1) Dcalage du cycle de la temprature et du CO2\n');
% (anti-correlation max entre t2moy (brut) et CO2 corrig) 
%-------------------------------------------------------------
rmin =  999999;
R=[];
for m=0:59 
    r = corrcoef([t2moy(1:Ndata-m ),CO2cor(m+1:Ndata)]);
    r = r(1,2);  R = [R, r];
    if (r<rmin) rmin=r; mmin=m; end
end
mstar = mod(mmin,12); % ici il se trouve que mstar=mmin, mais cela aurait pu ne pas etre le cas
disp(['corrlation min t2moy/CO2cor : r=',num2str(rmin),' pour m=',int2str(mmin),', m*=',int2str(mstar)]); %+
%
% Prsentation graphique
figure; plot(R,'-*'); axis tight;
set(gca,'XTick',[1:60], 'XTickLabel',[0:59]);
xlabel('nombre de mois en dcalage');
title('Coefficients de corrlation entre la srie des tempratures moyennes et celles du CO2 corrig dcal');
%
%-------------------------------------------------------------
fprintf('\n3.2) Comparaison des climatologie mensuelles\n')
% (i.e. comparaisons des moyennes mensuelles sur la priode, des
%  deux variables temprature et CO2)
%-------------------------------------------------------------
% => Construire d'abord, les moyennes par mois, sur toute la priode des donnes 
%    pour la temprature (t2moismoy) et le CO2 corrig (CO2cormoismoy)
for month=1:12
    Im = find(clim_t2(:,2)==month);
    t2moismoy(month)     = mean(t2moy(Im));
    CO2cormoismoy(month) = mean(CO2cor(Im));
end
%
figure;
%
% Labelisation des mois
monthlab={'janv','fev','mars','avril','mai','juin','juil','aout','sept','oct','nov','dec',}
%
% Moyenne par mois des tempratures
subplot(2,1,1); hold on
plot(t2moismoy,'*-'); axis tight;
set(gca,'XTick',[1:12], 'XTickLabel',monthlab);
title('moyenne par mois des tempratures')
%
% Moyenne par mois du CO2 corrig
subplot(2,1,2); hold on
plot(CO2cormoismoy,'*-'); axis tight;
title('moyenne par mois du CO2 corrig')
set(gca,'XTick',[1:12], 'XTickLabel',monthlab);
%
xlabel('mois')
%
%=============================================================
fprintf('\n4) Diagrammes de dispersion temprature/CO2\n');
%    (scatter plot t2moy / CO2, CO2cor, CO2cor dcal)
%-------------------------------------------------------------
figure;
%
% scatter plot t2moy / CO2
subplot(1,3,1); hold on;
plot(t2moy,clim_co2(:,3),'*'); axis tight;
regtrace(t2moy,clim_co2(:,3),'-m');
R=corrcoef([t2moy,clim_co2(:,3)]);
xlabel('t2moy'); ylabel('CO2');
title(['t2moy/CO2 (brut), r=',num2str(R(1,2))]);
%
% scatter plot t2moy / CO2cor
subplot(1,3,2); hold on;
plot(t2moy,CO2cor,'*');  axis tight;
regtrace(t2moy,CO2cor,'-m');
R=corrcoef([t2moy,CO2cor]);
xlabel('t2moy'); ylabel('CO2cor');
title(['t2moy/CO2cor, r=',num2str(R(1,2))]);
text(min(t2moy), max(CO2cor)+1, 'diagrammes de dispersion');
%
% scatter plot t2moy / CO2cor dcal (i.e : CO2cor+m*)
subplot(1,3,3); hold on;
plot(t2moy(1:Ndata-mstar),CO2cor(1+mstar:end),'*');  axis tight;
regtrace(t2moy(1:Ndata-mstar),CO2cor(1+mstar:end),'-m');
R=corrcoef([t2moy(1:Ndata-mstar),CO2cor(1+mstar:end)]);
xlabel('t2moy'); ylabel('CO2cor dcal');
title(['t2moy/CO2cor(dcal), r=',num2str(R(1,2))]);
%
%=============================================================
fprintf('\n5) Comparaison interannuelle des tempratures et du CO2\n');
%-------------------------------------------------------------
% => Calculer d'abord les moyennes annuelles des tempratures et du CO2
ia=1; % Indice de l'anne dans le vecteur  construire des moyennes annuelles
for an=1982:2010  %andeb:anfin
    Ian=find(clim_t2(:,1)==an);
    t2moyan(ia)  = mean(t2moy(Ian)); 
    CO2moyan(ia) = mean(clim_co2(Ian,3)); 
    ia=ia+1; 
end
%
R=corrcoef([t2moyan',CO2moyan']);  % Coefficient de corrlation
%
% Affichage graphique
h=figure; %set(h,'color','w');
dblyplot([1982:2010],t2moyan,CO2moyan,'Temprature C','CO2 ppm');
title(sprintf('Evolution compare des tempratures et du CO2 (r=%.3f)',R(1,2)));
%
%=============================================================
